pub struct Highlight {
pub foreground: Option<Color>,
pub background: Option<Color>,
pub style: Vec<StyleAttribute>,
}Expand description
Highlight definition.
Contains foreground and background colors as well as the style to use.
Fields
foreground: Option<Color>Foreground color.
Leaving it empty implies using the default foreground color of your terminal
background: Option<Color>Background color.
Leaving it empty implies using the default background color of your terminal
style: Vec<StyleAttribute>Style attributes to use.
Implementations